@@ -1,6 +1,6 @@
 /*
  * This file is part of dm-writeboost
- * Copyright (C) 2012-2018 Akira Hayakawa <ruby.wktk@gmail.com>
+ * Copyright (C) 2012-2020 Akira Hayakawa <ruby.wktk@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -528,4 +528,10 @@ sector_t dm_devsize(struct dm_dev *);
 
 /*----------------------------------------------------------------------------*/
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5,8,0)
+#define dm_blkdev_issue_flush(x, y) blkdev_issue_flush(x, y)
+#else
+#define dm_blkdev_issue_flush(x, y) blkdev_issue_flush(x, y, NULL)
+#endif
+
 #endif
